@@ -1,4 +1,7 @@
 package Task::BeLike::YANICK;
+BEGIN {
+  $Task::BeLike::YANICK::VERSION = '0.3.0';
+}
 
 use warnings;
 use strict;
@@ -7,6 +10,10 @@ use strict;
 
 Task::BeLike::YANICK - like Yanick? Be like Yanick!
 
+=head1 VERSION
+
+version 0.3.0
+
 =head1 SYNOPSIS
 
     $ cpan Task::BeLike::YANICK
@@ -16,6 +23,12 @@ Task::BeLike::YANICK - like Yanick? Be like Yanick!
 This L<Task> module installs the modules that I use on
 a regular basis.
 
+Wait, there is more! 
+It can also B<update> the modules that I use on a regular basis! 
+To do that, do
+
+    TASK_UPGRADE=1 cpan -f Task::BeLike::YANICK
+
 =head1 MODULES INSTALLED BY THIS TASK
 
 =head2 Object-Oriented Frameworks
@@ -121,19 +134,45 @@ Because tidy code is so easier to read.
 
 =item L<Perl::Critic>
 
+=item L<Module::Which>
+
+Which version of I<Foo::Bar> am I running, and in which lib directory
+is it hidding?
+
+=back
+
+=head2 CPAN
+
+=over
+
+=item L<CPAN::SQLite>
+
+CPAN asks for it, so there it is.
+
+=back
+
+=head2 Dist::Zilla
+
+=over
+
+=item L<Dist::Zilla>
+
+Rooooar!
+
+=item L<Dist::Zilla::Plugin::Git>
+
+Git-related Dist::Zilla actions.
+
+=item L<Dist::Zilla::Plugin::GithubMeta>
+
+Github actions.
 
 =back
 
 =for end_install
 
-=head1 VERSION
-
-Version 0.2.0
-
 =cut
 
-our $VERSION = '0.2.0';
-
 =head1 AUTHOR
 
 Yanick Champoux, C<< <yanick at cpan.org> >>
@@ -186,4 +225,4 @@ under the same terms as Perl itself.
 
 =cut
 
-1; # End of Task::BeLike::YANICK
+1; # End of Task::BeLike::YANICK
\ No newline at end of file
